@@ -20,7 +20,7 @@ import (
 const samplesDir = "../../sample-files"
 
 // Convert a cells array to a plain string
-func cellsToPlainString(cells []twin.Cell) string {
+func cellsToPlainString(cells []twin.StyledRune) string {
 	returnMe := ""
 	for _, cell := range cells {
 		returnMe += string(cell.Rune)
@@ -74,7 +74,7 @@ func TestTokenize(t *testing.T) {
 				var loglines strings.Builder
 				log.SetOutput(&loglines)
 
-				tokens := CellsFromString("", line, lineNumber).Cells
+				tokens := StyledRunesFromString("", line, lineNumber).StyledRunes
 				plainString := WithoutFormatting(line, lineNumber)
 				if len(tokens) != utf8.RuneCountInString(plainString) {
 					t.Errorf("%s:%s: len(tokens)=%d, len(plainString)=%d for: <%s>",
@@ -127,43 +127,43 @@ func TestTokenize(t *testing.T) {
 }
 
 func TestUnderline(t *testing.T) {
-	tokens := CellsFromString("", "a\x1b[4mb\x1b[24mc", nil).Cells
+	tokens := StyledRunesFromString("", "a\x1b[4mb\x1b[24mc", nil).StyledRunes
 	assert.Equal(t, len(tokens), 3)
-	assert.Equal(t, tokens[0], twin.Cell{Rune: 'a', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[1], twin.Cell{Rune: 'b', Style: twin.StyleDefault.WithAttr(twin.AttrUnderline)})
-	assert.Equal(t, tokens[2], twin.Cell{Rune: 'c', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[0], twin.StyledRune{Rune: 'a', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[1], twin.StyledRune{Rune: 'b', Style: twin.StyleDefault.WithAttr(twin.AttrUnderline)})
+	assert.Equal(t, tokens[2], twin.StyledRune{Rune: 'c', Style: twin.StyleDefault})
 }
 
 func TestManPages(t *testing.T) {
 	// Bold
-	tokens := CellsFromString("", "ab\bbc", nil).Cells
+	tokens := StyledRunesFromString("", "ab\bbc", nil).StyledRunes
 	assert.Equal(t, len(tokens), 3)
-	assert.Equal(t, tokens[0], twin.Cell{Rune: 'a', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[1], twin.Cell{Rune: 'b', Style: twin.StyleDefault.WithAttr(twin.AttrBold)})
-	assert.Equal(t, tokens[2], twin.Cell{Rune: 'c', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[0], twin.StyledRune{Rune: 'a', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[1], twin.StyledRune{Rune: 'b', Style: twin.StyleDefault.WithAttr(twin.AttrBold)})
+	assert.Equal(t, tokens[2], twin.StyledRune{Rune: 'c', Style: twin.StyleDefault})
 
 	// Underline
-	tokens = CellsFromString("", "a_\bbc", nil).Cells
+	tokens = StyledRunesFromString("", "a_\bbc", nil).StyledRunes
 	assert.Equal(t, len(tokens), 3)
-	assert.Equal(t, tokens[0], twin.Cell{Rune: 'a', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[1], twin.Cell{Rune: 'b', Style: twin.StyleDefault.WithAttr(twin.AttrUnderline)})
-	assert.Equal(t, tokens[2], twin.Cell{Rune: 'c', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[0], twin.StyledRune{Rune: 'a', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[1], twin.StyledRune{Rune: 'b', Style: twin.StyleDefault.WithAttr(twin.AttrUnderline)})
+	assert.Equal(t, tokens[2], twin.StyledRune{Rune: 'c', Style: twin.StyleDefault})
 
 	// Bullet point 1, taken from doing this on my macOS system:
 	// env PAGER="hexdump -C" man printf | moar
-	tokens = CellsFromString("", "a+\b+\bo\bob", nil).Cells
+	tokens = StyledRunesFromString("", "a+\b+\bo\bob", nil).StyledRunes
 	assert.Equal(t, len(tokens), 3)
-	assert.Equal(t, tokens[0], twin.Cell{Rune: 'a', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[1], twin.Cell{Rune: '•', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[2], twin.Cell{Rune: 'b', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[0], twin.StyledRune{Rune: 'a', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[1], twin.StyledRune{Rune: '•', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[2], twin.StyledRune{Rune: 'b', Style: twin.StyleDefault})
 
 	// Bullet point 2, taken from doing this using the "fish" shell on my macOS system:
 	// man printf | hexdump -C | moar
-	tokens = CellsFromString("", "a+\bob", nil).Cells
+	tokens = StyledRunesFromString("", "a+\bob", nil).StyledRunes
 	assert.Equal(t, len(tokens), 3)
-	assert.Equal(t, tokens[0], twin.Cell{Rune: 'a', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[1], twin.Cell{Rune: '•', Style: twin.StyleDefault})
-	assert.Equal(t, tokens[2], twin.Cell{Rune: 'b', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[0], twin.StyledRune{Rune: 'a', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[1], twin.StyledRune{Rune: '•', Style: twin.StyleDefault})
+	assert.Equal(t, tokens[2], twin.StyledRune{Rune: 'b', Style: twin.StyleDefault})
 }
 
 func TestManPageHeadings(t *testing.T) {
@@ -181,18 +181,18 @@ func TestManPageHeadings(t *testing.T) {
 	}
 
 	// A line with only man page bold caps should be considered a heading
-	for _, token := range CellsFromString("", manPageHeading, nil).Cells {
+	for _, token := range StyledRunesFromString("", manPageHeading, nil).StyledRunes {
 		assert.Equal(t, token.Style, ManPageHeading)
 	}
 
 	// A line with only non-man-page bold caps should not be considered a heading
 	wrongKindOfBold := "\x1b[1mJOHAN HELLO"
-	for _, token := range CellsFromString("", wrongKindOfBold, nil).Cells {
+	for _, token := range StyledRunesFromString("", wrongKindOfBold, nil).StyledRunes {
 		assert.Equal(t, token.Style, twin.StyleDefault.WithAttr(twin.AttrBold))
 	}
 
 	// A line with not all caps should not be considered a heading
-	for _, token := range CellsFromString("", notAllCaps, nil).Cells {
+	for _, token := range StyledRunesFromString("", notAllCaps, nil).StyledRunes {
 		assert.Equal(t, token.Style, twin.StyleDefault.WithAttr(twin.AttrBold))
 	}
 }
@@ -257,9 +257,9 @@ func TestRawUpdateStyle(t *testing.T) {
 func TestHyperlink_escBackslash(t *testing.T) {
 	url := "http://example.com"
 
-	tokens := CellsFromString("", "a\x1b]8;;"+url+"\x1b\\bc\x1b]8;;\x1b\\d", nil).Cells
+	tokens := StyledRunesFromString("", "a\x1b]8;;"+url+"\x1b\\bc\x1b]8;;\x1b\\d", nil).StyledRunes
 
-	assert.DeepEqual(t, tokens, []twin.Cell{
+	assert.DeepEqual(t, tokens, []twin.StyledRune{
 		{Rune: 'a', Style: twin.StyleDefault},
 		{Rune: 'b', Style: twin.StyleDefault.WithHyperlink(&url)},
 		{Rune: 'c', Style: twin.StyleDefault.WithHyperlink(&url)},
@@ -273,9 +273,9 @@ func TestHyperlink_escBackslash(t *testing.T) {
 func TestHyperlink_bell(t *testing.T) {
 	url := "http://example.com"
 
-	tokens := CellsFromString("", "a\x1b]8;;"+url+"\x07bc\x1b]8;;\x07d", nil).Cells
+	tokens := StyledRunesFromString("", "a\x1b]8;;"+url+"\x07bc\x1b]8;;\x07d", nil).StyledRunes
 
-	assert.DeepEqual(t, tokens, []twin.Cell{
+	assert.DeepEqual(t, tokens, []twin.StyledRune{
 		{Rune: 'a', Style: twin.StyleDefault},
 		{Rune: 'b', Style: twin.StyleDefault.WithHyperlink(&url)},
 		{Rune: 'c', Style: twin.StyleDefault.WithHyperlink(&url)},
@@ -286,7 +286,7 @@ func TestHyperlink_bell(t *testing.T) {
 // Test with some other ESC sequence than ESC-backslash
 func TestHyperlink_nonTerminatingEsc(t *testing.T) {
 	complete := "a\x1b]8;;https://example.com\x1bbc"
-	tokens := CellsFromString("", complete, nil).Cells
+	tokens := StyledRunesFromString("", complete, nil).StyledRunes
 
 	// This should not be treated as any link
 	for i := 0; i < len(complete); i++ {
@@ -295,7 +295,7 @@ func TestHyperlink_nonTerminatingEsc(t *testing.T) {
 			// good enough.
 			continue
 		}
-		assert.Equal(t, tokens[i], twin.Cell{Rune: rune(complete[i]), Style: twin.StyleDefault},
+		assert.Equal(t, tokens[i], twin.StyledRune{Rune: rune(complete[i]), Style: twin.StyleDefault},
 			"i=%d, c=%s, tokens=%v", i, string(complete[i]), tokens)
 	}
 }
@@ -306,7 +306,7 @@ func TestHyperlink_incomplete(t *testing.T) {
 	for l := len(complete) - 1; l >= 0; l-- {
 		incomplete := complete[:l]
 		t.Run(fmt.Sprintf("l=%d incomplete=<%s>", l, strings.ReplaceAll(incomplete, "\x1b", "ESC")), func(t *testing.T) {
-			tokens := CellsFromString("", incomplete, nil).Cells
+			tokens := StyledRunesFromString("", incomplete, nil).StyledRunes
 
 			for i := 0; i < l; i++ {
 				if complete[i] == '\x1b' {
@@ -314,7 +314,7 @@ func TestHyperlink_incomplete(t *testing.T) {
 					// that's good enough.
 					continue
 				}
-				assert.Equal(t, tokens[i], twin.Cell{Rune: rune(complete[i]), Style: twin.StyleDefault})
+				assert.Equal(t, tokens[i], twin.StyledRune{Rune: rune(complete[i]), Style: twin.StyleDefault})
 			}
 		})
 	}
